pub fn parse_millis(s: &str) -> Result<Duration, ParseIntError>Expand description
Parses the string as a number of milliseconds into a Duration.
pub fn parse_millis(s: &str) -> Result<Duration, ParseIntError>Parses the string as a number of milliseconds into a Duration.