pub fn parse_millis_delta(s: &str) -> Result<TimeDelta, ParseIntError>Expand description
Parses the string as a number of milliseconds into a TimeDelta.
pub fn parse_millis_delta(s: &str) -> Result<TimeDelta, ParseIntError>Parses the string as a number of milliseconds into a TimeDelta.